@@ -3,8 +3,19 @@
 tam.jml <- function( resp , group = NULL , adj=.3 , disattenuate = FALSE ,
             bias = TRUE, xsi.fixed=NULL ,  xsi.inits = NULL ,  theta.fixed = NULL , 
             A=NULL , B=NULL , Q=NULL , ndim=1 ,
-            pweights = NULL , control = list() , version = 2 )
-{           
+            pweights = NULL , verbose = TRUE , control = list() , version = 2 )
+{           	
+	CALL <- match.call()
+	#**** handle verbose argument	
+	args_CALL <- as.list( sys.call() )
+	control$progress <- tam_args_CALL_search( args_CALL=args_CALL , variable="verbose" , 
+								default_value = TRUE )				
+	#*******
+	if ( ! is.null(theta.fixed) ){
+		version <- 1
+	}
+	
+	
 	#**** version = 1
 	if (version == 1){
 		res <- tam_jml_version1( resp=resp , group = group , adj=adj , 
@@ -21,5 +32,6 @@ tam.jml <- function( resp , group = NULL , adj=.3 , disattenuate = FALSE ,
 				A=A , B=B , Q=Q , ndim=ndim ,
 				pweights = pweights , control = control  )
 	}
+	res$CALL <- CALL
 	return(res)	
 }
\ No newline at end of file
